@@ -1,6 +1,6 @@
 from django import forms
 from django.core.exceptions import ValidationError
-from django.test import TestCase, tag
+from django.test import TestCase
 from edc_constants.constants import NO, NOT_APPLICABLE, OTHER, POS, YES
 from edc_registration.models import RegisteredSubject
 from edc_utils import get_utcnow
@@ -33,39 +33,39 @@ class TestMicrobiologyFormValidator(TestCase):
             appointment=appointment, subject_identifier=self.subject_identifier
         )
 
-    def test_urine_culture_performed_yes_require_urine_culture_results(self):
+    def test_urine_culture_performed_yes_require_urine_culture_result(self):
         cleaned_data = {
             "subject_visit": self.subject_visit,
             "urine_culture_performed": YES,
-            "urine_taken_date": get_utcnow(),
-            "urine_culture_results": NOT_APPLICABLE,
+            "urine_culture_date": get_utcnow(),
+            "urine_culture_result": NOT_APPLICABLE,
         }
         form_validator = MicrobiologyFormValidator(cleaned_data=cleaned_data)
         self.assertRaises(ValidationError, form_validator.validate)
-        self.assertIn("urine_culture_results", form_validator._errors)
+        self.assertIn("urine_culture_result", form_validator._errors)
 
-    def test_urine_culture_performed_no_require_urine_culture_results(self):
+    def test_urine_culture_performed_no_require_urine_culture_result(self):
         cleaned_data = {
             "subject_visit": self.subject_visit,
             "urine_culture_performed": NO,
-            "urine_culture_results": NO_GROWTH,
+            "urine_culture_result": NO_GROWTH,
         }
         form_validator = MicrobiologyFormValidator(cleaned_data=cleaned_data)
         self.assertRaises(ValidationError, form_validator.validate)
 
-    def test_urine_culture_performed_na_given_urine_culture_results(self):
+    def test_urine_culture_performed_na_given_urine_culture_result(self):
         cleaned_data = {
             "subject_visit": self.subject_visit,
             "urine_culture_performed": YES,
-            "urine_culture_results": NOT_APPLICABLE,
+            "urine_culture_result": NOT_APPLICABLE,
         }
         form_validator = MicrobiologyFormValidator(cleaned_data=cleaned_data)
         self.assertRaises(ValidationError, form_validator.validate)
 
-    def test_pos_urine_culture_results_none_urine_culture_organism(self):
+    def test_pos_urine_culture_result_none_urine_culture_organism(self):
         cleaned_data = {
             "subject_visit": self.subject_visit,
-            "urine_culture_results": POS,
+            "urine_culture_result": POS,
             "urine_culture_organism": NOT_APPLICABLE,
         }
         form_validator = MicrobiologyFormValidator(cleaned_data=cleaned_data)
@@ -75,7 +75,7 @@ class TestMicrobiologyFormValidator(TestCase):
     def test_pos_urine_results_na_urine_culture_organism(self):
         cleaned_data = {
             "subject_visit": self.subject_visit,
-            "urine_culture_results": POS,
+            "urine_culture_result": POS,
             "urine_culture_organism": NOT_APPLICABLE,
         }
         form_validator = MicrobiologyFormValidator(cleaned_data=cleaned_data)
@@ -84,7 +84,7 @@ class TestMicrobiologyFormValidator(TestCase):
     def test_pos_urine_results_with_urine_culture_organism(self):
         cleaned_data = {
             "subject_visit": self.subject_visit,
-            "urine_culture_results": POS,
+            "urine_culture_result": POS,
             "urine_culture_organism": KLEBSIELLA_SPP,
         }
         form_validator = MicrobiologyFormValidator(cleaned_data=cleaned_data)
@@ -93,7 +93,7 @@ class TestMicrobiologyFormValidator(TestCase):
         except forms.ValidationError as e:
             self.fail(f"ValidationError unexpectedly raised. Got{e}")
 
-    def test_other_urine_culture_results_require_urine_organism_other(self):
+    def test_other_urine_culture_result_require_urine_organism_other(self):
         cleaned_data = {
             "subject_visit": self.subject_visit,
             "urine_culture_organism": OTHER,
@@ -107,6 +107,7 @@ class TestMicrobiologyFormValidator(TestCase):
         cleaned_data = {
             "subject_visit": self.subject_visit,
             "blood_culture_performed": YES,
+            "blood_culture_date": get_utcnow(),
             "blood_culture_result": NOT_APPLICABLE,
         }
         form_validator = MicrobiologyFormValidator(cleaned_data=cleaned_data)
@@ -230,20 +231,11 @@ class TestMicrobiologyFormValidator(TestCase):
         form_validator = MicrobiologyFormValidator(cleaned_data=cleaned_data)
         self.assertRaises(ValidationError, form_validator.validate)
 
-    def test_pos_sputum_results_culture_require_sputum_results_positive(self):
+    def test_pos_sputum_results_culture_require_sputum_result(self):
         cleaned_data = {
             "subject_visit": self.subject_visit,
-            "sputum_culture_result": POS,
-            "sputum_culture_result_positive": None,
-        }
-        form_validator = MicrobiologyFormValidator(cleaned_data=cleaned_data)
-        self.assertRaises(ValidationError, form_validator.validate)
-
-    def test_pos_sputum_results_culture_na_sputum_results_positive(self):
-        cleaned_data = {
-            "subject_visit": self.subject_visit,
-            "sputum_culture_result": POS,
-            "sputum_culture_result_positive": NOT_APPLICABLE,
+            "sputum_culture_performed": YES,
+            "sputum_culture_result": None,
         }
         form_validator = MicrobiologyFormValidator(cleaned_data=cleaned_data)
         self.assertRaises(ValidationError, form_validator.validate)
@@ -252,7 +244,6 @@ class TestMicrobiologyFormValidator(TestCase):
         cleaned_data = {
             "subject_visit": self.subject_visit,
             "sputum_culture_result": POS,
-            "sputum_culture_result_positive": "Value results_positive",
         }
         form_validator = MicrobiologyFormValidator(cleaned_data=cleaned_data)
         try:
@@ -260,80 +251,80 @@ class TestMicrobiologyFormValidator(TestCase):
         except forms.ValidationError as e:
             self.fail(f"ValidationError unexpectedly raised. Got{e}")
 
-    def test_tissue_biopsy_taken_require_tissue_biopsy_results(self):
+    def test_tissue_biopsy_performed_require_tissue_biopsy_result(self):
         cleaned_data = {
             "subject_visit": self.subject_visit,
-            "tissue_biopsy_taken": YES,
-            "tissue_biopsy_results": None,
+            "tissue_biopsy_performed": YES,
+            "tissue_biopsy_result": None,
         }
         form_validator = MicrobiologyFormValidator(cleaned_data=cleaned_data)
         self.assertRaises(ValidationError, form_validator.validate)
 
-    def test_no_tissue_biopsy_taken_none_tissue_biopsy_results(self):
+    def test_no_tissue_biopsy_performed_none_tissue_biopsy_result(self):
         cleaned_data = {
             "subject_visit": self.subject_visit,
-            "tissue_biopsy_taken": NO,
-            "tissue_biopsy_results": POS,
+            "tissue_biopsy_performed": NO,
+            "tissue_biopsy_result": POS,
         }
         form_validator = MicrobiologyFormValidator(cleaned_data=cleaned_data)
         self.assertRaises(ValidationError, form_validator.validate)
-        self.assertIn("tissue_biopsy_results", form_validator._errors)
+        self.assertIn("tissue_biopsy_result", form_validator._errors)
 
-    def no_test_tissue_biopsy_taken_with_tissue_biopsy_results(self):
+    def no_test_tissue_biopsy_performed_with_tissue_biopsy_result(self):
         cleaned_data = {
             "subject_visit": self.subject_visit,
-            "tissue_biopsy_taken": NO,
-            "tissue_biopsy_results": NO_GROWTH,
+            "tissue_biopsy_performed": NO,
+            "tissue_biopsy_result": NO_GROWTH,
         }
         form_validator = MicrobiologyFormValidator(cleaned_data=cleaned_data)
         self.assertRaises(ValidationError, form_validator.validate)
 
-    def test_pos_tissue_biopsy_results_none_biopsy_date(self):
+    def test_pos_tissue_biopsy_result_none_biopsy_date(self):
         cleaned_data = {
             "subject_visit": self.subject_visit,
-            "tissue_biopsy_taken": NO,
-            "biopsy_date": get_utcnow().date(),
+            "tissue_biopsy_performed": NO,
+            "tissue_biopsy_date": get_utcnow().date(),
         }
         form_validator = MicrobiologyFormValidator(cleaned_data=cleaned_data)
         self.assertRaises(ValidationError, form_validator.validate)
 
-    def test_pos_tissue_biopsy_results_na_biopsy_date(self):
+    def test_pos_tissue_biopsy_result_na_tissue_biopsy_date(self):
         cleaned_data = {
             "subject_visit": self.subject_visit,
-            "tissue_biopsy_taken": YES,
-            "biopsy_date": None,
+            "tissue_biopsy_performed": YES,
+            "tissue_biopsy_date": None,
         }
         form_validator = MicrobiologyFormValidator(cleaned_data=cleaned_data)
         self.assertRaises(ValidationError, form_validator.validate)
-        self.assertIn("biopsy_date", form_validator._errors)
+        self.assertIn("tissue_biopsy_date", form_validator._errors)
 
-    def test_pos_tissue_biopsy_results_with_day_biopsy_taken(self):
+    def test_pos_tissue_biopsy_result_with_tissue_biopsy_day(self):
         cleaned_data = {
             "subject_visit": self.subject_visit,
-            "tissue_biopsy_taken": YES,
-            "biopsy_date": get_utcnow(),
-            "tissue_biopsy_results": POS,
-            "day_biopsy_taken": None,
+            "tissue_biopsy_performed": YES,
+            "tissue_biopsy_date": get_utcnow(),
+            "tissue_biopsy_result": POS,
+            "tissue_biopsy_day": None,
         }
         form = MicrobiologyFormValidator(cleaned_data=cleaned_data)
         self.assertRaises(ValidationError, form.validate)
-        self.assertIn("day_biopsy_taken", form._errors)
+        self.assertIn("tissue_biopsy_day", form._errors)
 
-    def test_pos_tissue_biopsy_results_none_tissue_biopsy_organism(self):
+    def test_pos_tissue_biopsy_result_none_tissue_biopsy_organism(self):
         cleaned_data = {
             "subject_visit": self.subject_visit,
-            "tissue_biopsy_taken": YES,
-            "biopsy_date": get_utcnow(),
-            "tissue_biopsy_results": POS,
+            "tissue_biopsy_performed": YES,
+            "tissue_biopsy_date": get_utcnow(),
+            "tissue_biopsy_result": POS,
             "tissue_biopsy_organism": None,
         }
         form_validator = MicrobiologyFormValidator(cleaned_data=cleaned_data)
         self.assertRaises(ValidationError, form_validator.validate)
 
-    def test_pos_tissue_biopsy_results_na_tissue_biopsy_organism(self):
+    def test_pos_tissue_biopsy_result_na_tissue_biopsy_organism(self):
         cleaned_data = {
             "subject_visit": self.subject_visit,
-            "tissue_biopsy_results": POS,
+            "tissue_biopsy_result": POS,
             "tissue_biopsy_organism": NOT_APPLICABLE,
         }
         form_validator = MicrobiologyFormValidator(cleaned_data=cleaned_data)
